import yt_dlp


def download(url: list | str = '', output_folder: str = '.', audio_only: bool = False):
    """
    Downloads YouTube video(s) provided in the url(s).

    Args:
        url: A single YouTube video URL or a list of URLs.
        output_folder: The folder where the video(s) will be saved.
        audio_only: Flag to specify if only audio should be downloaded.

    Returns:
    """
    # If a single URL is provided (string), convert it to a list
    if isinstance(url, str):
        url = [url]

    # Set the format for downloading (audio only if specified)
    if audio_only:
        options = {
            'format': 'bestaudio/best',  # Download only the best audio
            'outtmpl': f'{output_folder}/%(title)s.%(ext)s',  # Save with video title as filename
        }
    else:
        options = {
            'format': 'best',  # Download the best video
            'outtmpl': f'{output_folder}/%(title)s.%(ext)s',  # Save with video title as filename
        }

    try:
        with yt_dlp.YoutubeDL(options) as ydl:
            print("\nDownloading video(s)..." if not audio_only else "\nDownloading audio(s)...")
            ydl.download(url)  # Download all URLs in the list
            print("Download(s) completed successfully!")
    except Exception as e:
        print(f"An error occurred: {e}")


if __name__ == "__main__":
    # Example with a single URL, downloading audio only
    download(url='https://www.youtube.com/watch?v=jJcqew3dQ9g', audio_only=True)

    # Example with multiple URLs, downloading video
    # download(url=['https://www.youtube.com/watch?v=jJcqew3dQ9g', 'https://www.youtube.com/watch?v=ItRw0A_xyEU'], audio_only=False)
